==> subtitleeditor_0.10.1.orig.tar.gz: subtitleeditor-0.10.1/src/Color.h <==
#ifndef _Color_h
#define _Color_h

/*
 *	subtitle editor
 *
 *	http://kitone.free.fr/subtitleeditor/
 *
 *	Copyright @ 2005-2006, kitone
 *
 *	Contact: kitone at free dot fr
 *
 *	This program is free software; you can redistribute it and/or
 *	modify it under the terms of the GNU General Public
 *	License as published by the Free Software Foundation; either
 *	version 2 of the License, or (at your option) any later version.
 *
 *	This program is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	See the GNU
 *	General Public License for more details.
 *
 *	You should have received a copy of the GNU General Public
 *	License along with this program; if not, write to the Free Software
 *	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA	02111-1307	USA
 *
 *	See gpl.txt for more information regarding the GNU General Public License.
 *
 *
 *	\file
 *	\brief 
 *	\author kitone (kitone at free dot fr)
 */

#include <gdkmm/color.h>
#include <gtkmm/colorbutton.h>



/*
 *	clamp [0, 255] for color
 */
class Color
{
public:
	Color();
	Color(unsigned int r, unsigned int g, unsigned int b, unsigned int a);
	//Color(const Gdk::Color &gdkcolor, unsigned int alpha);
	
	/*
	 *
	 */
	void set(unsigned int r, unsigned int g, unsigned int b, unsigned a=255);
	void set(unsigned int rgba);
	void set(unsigned int rgb, unsigned int alpha);
	/*
	 *	for SSA
	 */
	unsigned int getRGB();


	/*
	 *	for ASS
	 */
	unsigned int getRGBA();


	/*
	 *
	 */
	unsigned int getR();
	unsigned int getG();
	unsigned int getB();
	unsigned int getA();


	/*
	 *
	 */
	//void setGdkColor(const Gdk::Color &color, unsigned int alpha=255);

	/*
	 *
	 */
	//Gdk::Color getGdkColor();


	/*
	 *	init button avec les info de color
	 */
	void initColorButton(Gtk::ColorButton &button);

	/*
	 *	init color a partir de button
	 */
	void getFromColorButton(const Gtk::ColorButton &button);

protected:
	unsigned int rgba;
};

#endif//_Color_h

==> subtitleeditor_0.13.6.orig.tar.gz: subtitleeditor-0.13.6/src/Color.h <==
#ifndef _Color_h
#define _Color_h

/*
 *	subtitle editor
 *
 *	http://kitone.free.fr/subtitleeditor/
 *
 *	Copyright @ 2005-2006, kitone
 *
 *	Contact: kitone at free dot fr
 *
 *	This program is free software; you can redistribute it and/or
 *	modify it under the terms of the GNU General Public
 *	License as published by the Free Software Foundation; either
 *	version 2 of the License, or (at your option) any later version.
 *
 *	This program is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	See the GNU
 *	General Public License for more details.
 *
 *	You should have received a copy of the GNU General Public
 *	License along with this program; if not, write to the Free Software
 *	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA	02111-1307	USA
 *
 *	See gpl.txt for more information regarding the GNU General Public License.
 *
 *
 *	\file
 *	\brief 
 *	\author kitone (kitone at free dot fr)
 */

#include <gdkmm/color.h>
#include <gtkmm/colorbutton.h>



/*
 *	clamp [0, 255] for color
 */
class Color
{
public:
	Color();
	Color(unsigned int r, unsigned int g, unsigned int b, unsigned int a);
	
	/*
	 *
	 */
	void set(unsigned int r, unsigned int g, unsigned int b, unsigned a=255);
	//void set(unsigned int rgba);
	//void set(unsigned int rgb, unsigned int alpha);

	/*
	 *	for SSA
	 */
	//unsigned int getRGB();


	/*
	 *	for ASS
	 */
	//unsigned int getRGBA();


	/*
	 *
	 */
	unsigned int getR();
	unsigned int getG();
	unsigned int getB();
	unsigned int getA();

	/*
	 *	init button avec les info de color
	 */
	void initColorButton(Gtk::ColorButton &button);

	/*
	 *	init color a partir de button
	 */
	void getFromColorButton(const Gtk::ColorButton &button);

protected:
	//unsigned int rgba;
	unsigned int m_rgba[4];
};

#endif//_Color_h
